package Data::Unixish::ansi;

use 5.010001;
use strict;
use warnings;

our $VERSION = '0.03'; # VERSION

1;
# ABSTRACT: dux functions related to text containing ANSI codes

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Unixish::ansi - dux functions related to text containing ANSI codes

=head1 VERSION

version 0.03

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 SEE ALSO

L<Data::Unixish>

L<dux>

L<Text::ANSI::Util>

L<Term::ANSIColor>

L<Term::ANSIScreen>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish-ansi>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish-ansi>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish-ansi>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
